aboutsummaryrefslogtreecommitdiff
path: root/kernel/include/rpmsg/ethosu_rpmsg_cancel_inference.h
diff options
context:
space:
mode:
Diffstat (limited to 'kernel/include/rpmsg/ethosu_rpmsg_cancel_inference.h')
-rw-r--r--kernel/include/rpmsg/ethosu_rpmsg_cancel_inference.h34
1 files changed, 17 insertions, 17 deletions
diff --git a/kernel/include/rpmsg/ethosu_rpmsg_cancel_inference.h b/kernel/include/rpmsg/ethosu_rpmsg_cancel_inference.h
index 1d6cc03..799b006 100644
--- a/kernel/include/rpmsg/ethosu_rpmsg_cancel_inference.h
+++ b/kernel/include/rpmsg/ethosu_rpmsg_cancel_inference.h
@@ -17,8 +17,8 @@
* http://www.gnu.org/licenses/gpl-2.0.html.
*/
-#ifndef ETHOSU_CANCEL_INFERENCE_H
-#define ETHOSU_CANCEL_INFERENCE_H
+#ifndef ETHOSU_RPMSG_CANCEL_INFERENCE_H
+#define ETHOSU_RPMSG_CANCEL_INFERENCE_H
/****************************************************************************
* Includes
@@ -34,16 +34,16 @@
* Types
****************************************************************************/
-struct ethosu_core_msg_cancel_inference_rsp;
-struct ethosu_inference;
+struct ethosu_rpmsg_cancel_inference_rsp;
+struct ethosu_rpmsg_inference;
struct ethosu_uapi_cancel_inference_status;
-struct ethosu_cancel_inference {
+struct ethosu_rpmsg_cancel_inference {
struct device *dev;
- struct ethosu_inference *inf;
+ struct ethosu_rpmsg_inference *inf;
struct ethosu_uapi_cancel_inference_status *uapi;
struct completion done;
- struct ethosu_mailbox_msg msg;
+ struct ethosu_rpmsg_mailbox_msg msg;
int errno;
};
@@ -52,20 +52,20 @@ struct ethosu_cancel_inference {
****************************************************************************/
/**
* ethosu_cancel_inference_request() - Send cancel inference request
*
* Return: 0 on success, error code otherwise.
*/
-int ethosu_cancel_inference_request(struct device *dev,
- struct ethosu_mailbox *mailbox,
- struct ethosu_inference *inf,
- struct ethosu_uapi_cancel_inference_status *uapi);
+int ethosu_rpmsg_cancel_inference_request(struct device *dev,
+ struct ethosu_rpmsg_mailbox *mailbox,
+ struct ethosu_rpmsg_inference *inf,
+ struct ethosu_uapi_cancel_inference_status *uapi);
/**
* ethosu_cancel_inference_rsp() - Handle cancel inference response
*/
-void ethosu_cancel_inference_rsp(struct ethosu_mailbox *mailbox,
- int msg_id,
- struct ethosu_core_msg_cancel_inference_rsp *rsp);
+void ethosu_rpmsg_cancel_inference_rsp(struct ethosu_rpmsg_mailbox *mailbox,
+ int msg_id,
+ struct ethosu_rpmsg_cancel_inference_rsp *rsp);
-#endif /* ETHOSU_CANCEL_INFERENCE_H */
+#endif /* ETHOSU_RPMSG_CANCEL_INFERENCE_H */
@@ -52,20 +52,20 @@ struct ethosu_cancel_inference {
****************************************************************************/
/**
- * ethosu_cancel_inference_request() - Send cancel inference request
+ * ethosu_rpmsg_cancel_inference_request() - Send cancel inference request
*
* Return: 0 on success, error code otherwise.
@@ -52,20 +52,20 @@ struct ethosu_cancel_inference {
/**
- * ethosu_cancel_inference_rsp() - Handle cancel inference response
+ * ethosu_rpmsg_cancel_inference_rsp() - Handle cancel inference response
*/